@@ -18,9 +18,15 @@ import base64
 from typing import List, Tuple, Optional, Union, Type
 from collections import OrderedDict
 import sys
-from salesforce.custom_exceptions.salesforce_exceptions import *
-from salesforce.utilities.df_utils import *
-from salesforce.decorators import *
+sys.path.append("..")
+try:
+    from custom_exceptions.salesforce_exceptions import *
+    from utilities.df_utils import *
+    from decorators import *
+except:
+    from salesforce.custom_exceptions.salesforce_exceptions import *
+    from salesforce.utilities.df_utils import *
+    from salesforce.decorators import *
 
 
 
